@@ -1,7 +1,7 @@
 /*
  * internal.h: Useful definitions
  *
- * Copyright (C) 2007-2011 David Lutterkort
+ * Copyright (C) 2007-2015 David Lutterkort
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -36,6 +36,7 @@
 #include <errno.h>
 #include <assert.h>
 #include <locale.h>
+#include <stdint.h>
 
 /*
  * Various parameters about env vars, special tree nodes etc.
@@ -377,6 +378,8 @@ struct tree {
     struct tree *children;   /* List of children through NEXT */
     char        *value;
     int          dirty;
+    uint8_t      added;      /* only used by ns_add and tree_rm to dedupe
+                                nodesets */
     struct span *span;
 };
 
