@@ -1,7 +1,7 @@
 /*
  * lens.c:
  *
- * Copyright (C) 2007-2011 David Lutterkort
+ * Copyright (C) 2007-2015 David Lutterkort
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -1061,6 +1061,10 @@ void lens_release(struct lens *lens) {
  * Encoding of tree levels
  */
 char *enc_format(const char *e, size_t len) {
+    return enc_format_indent(e, len, 0);
+}
+
+char *enc_format_indent(const char *e, size_t len, int indent) {
     size_t size = 0;
     char *result = NULL, *r;
     const char *k = e;
@@ -1073,6 +1077,8 @@ char *enc_format(const char *e, size_t len) {
         assert(slash != NULL);
         v = eq + 1;
 
+        if (indent > 0)
+            size += indent + 1;
         size += 6;     /* Surrounding braces */
         if (k != eq)
             size += 1 + (eq - k) + 1;
@@ -1092,6 +1098,8 @@ char *enc_format(const char *e, size_t len) {
         assert(eq != NULL && slash != NULL);
         v = eq + 1;
 
+        for (int i=0; i < indent; i++)
+            *r++ = ' ';
         r = stpcpy(r, " { ");
         if (k != eq) {
             r = stpcpy(r, "\"");
@@ -1104,6 +1112,8 @@ char *enc_format(const char *e, size_t len) {
             r = stpcpy(r, "\"");
         }
         r = stpcpy(r, " }");
+        if (indent > 0)
+            *r++ = '\n';
         k = slash + 1;
     }
     return result;
@@ -1246,13 +1256,20 @@ static int format_union_atype(struct lens *l, char **buf, uint indent) {
     if (ALLOC_N(c, l->nchildren) < 0)
         goto done;
 
+    /* Estimate the length of the string we will build. The calculation
+       overestimates that length so that the logic is a little simpler than
+       in the loop where we actually build the string */
     for (int i=0; i < l->nchildren; i++) {
         r = format_atype(l->children[i], c+i, indent + 2);
         if (r < 0)
             goto done;
-        len += strlen(c[i]) + 3;
+        /* We will add c[i] and some fixed characters */
+        len += strlen(c[i]) + strlen("\n| ()");
+        if (strlen(c[i]) < indent+2) {
+            /* We will add indent+2 whitespace */
+            len += indent+2;
+        }
     }
-    len += l->nchildren - 1;
 
     if (ALLOC_N(s, len+1) < 0)
         goto done;
@@ -1263,9 +1280,12 @@ static int format_union_atype(struct lens *l, char **buf, uint indent) {
         if (i > 0) {
             *p++ = '\n';
             if (strlen(t) >= indent+2) {
+                /* c[i] is not just whitespace */
                 p = stpncpy(p, t, indent+2);
                 t += indent+2;
             } else {
+                /* c[i] is just whitespace, make sure we indent the
+                   '|' appropriately */
                 memset(p, ' ', indent+2);
                 p += indent+2;
             }
