@@ -1,7 +1,7 @@
 /*
  * lens.h: Repreentation of lenses
  *
- * Copyright (C) 2007-2011 David Lutterkort
+ * Copyright (C) 2007-2015 David Lutterkort
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -170,6 +170,8 @@ struct skel {
 
 struct lns_error {
     struct lens  *lens;
+    struct lens  *last;       /* The last lens that matched */
+    struct lens  *next;       /* The next lens that should match but doesn't */
     int           pos;        /* Errors from get/parse */
     char         *path;       /* Errors from put, pos will be -1 */
     char         *message;
@@ -247,6 +249,12 @@ void free_lens(struct lens *lens);
  *    { key1 = value1 } { key2 = value2 } .. { keyN = valueN }
  */
 char *enc_format(const char *e, size_t len);
+/* Format an encoded level similar to ENC_FORMAT, but put each tree node
+ * on a new line indented by INDENT spaces. If INDENT is negative, produce the
+ * same output as ENC_FORMAT
+ *    { key1 = value1 } { key2 = value2 } .. { keyN = valueN }
+ */
+char *enc_format_indent(const char *e, size_t len, int indent);
 
 #if ENABLE_DEBUG
 void dump_lens_tree(struct lens *lens);
